@@ -6,7 +6,7 @@ from datetime import datetime
 def run(data,date_column:str,sku_column:str,store_column:str,num_ordering_types:int,
         ordering_columns:list, demand_column:str,date_start:str,date_end:str,shelf_life:int,output_filepath:str):
     
-    results=pd.DataFrame()
+    results=[]
     data[date_column] = data[date_column].apply(lambda x: datetime.strptime(x,"%Y-%m-%d"))
     data.sort_values(by=date_column,inplace=True)
     date_start = datetime.strptime(date_start,"%Y-%m-%d")
@@ -16,16 +16,16 @@ def run(data,date_column:str,sku_column:str,store_column:str,num_ordering_types:
 
     for ord_type in range(num_ordering_types):
         ord_col = ordering_columns[ord_type]
-        data = data[[date_column,store_column,sku_column,ord_col,demand_column]]
+        data_temp = data[[date_column,store_column,sku_column,ord_col,demand_column]]
         days = len(data)
-        number = len(data[store_column].unique())*len(data[sku_column].unique())
+        number = len(data_temp[store_column].unique())*len(data_temp[sku_column].unique())
 
-        q = initialize(ord_col,shelf_life,data,number)
-        res = run_simulation(q,days,data)
+        q = initialize(ord_col,shelf_life,data_temp,number)
+        res = run_simulation(q,days,data_temp)
         res = empty(res,q)
-        results = results.append(res)
-
-    return results
+        results.append(res)
+    results_df = pd.concat(results,axis= 1, join="inner")
+    return results_df
 
     
 
